GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2CacheCapabilities (google_api_remote_build_execution v0.23.0) View Source
Capabilities of the remote cache system.
Attributes
-
actionCacheUpdateCapabilities(type:GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2ActionCacheUpdateCapabilities.t, default:nil) - Capabilities for updating the action cache. -
cachePriorityCapabilities(type:GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2PriorityCapabilities.t, default:nil) - Supported cache priority range for both CAS and ActionCache. -
digestFunctions(type:list(String.t), default:nil) - All the digest functions supported by the remote cache. Remote cache may support multiple digest functions simultaneously. -
maxBatchTotalSizeBytes(type:String.t, default:nil) - Maximum total size of blobs to be uploaded/downloaded using batch methods. A value of 0 means no limit is set, although in practice there will always be a message size limitation of the protocol in use, e.g. GRPC. -
supportedCompressors(type:list(String.t), default:nil) - Compressors supported by the "compressed-blobs" bytestream resources. Servers MUST support identity/no-compression, even if it is not listed here. Note that this does not imply which if any compressors are supported by the server at the gRPC level. -
symlinkAbsolutePathStrategy(type:String.t, default:nil) - Whether absolute symlink targets are supported.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() ::
%GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2CacheCapabilities{
actionCacheUpdateCapabilities:
GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2ActionCacheUpdateCapabilities.t()
| nil,
cachePriorityCapabilities:
GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2PriorityCapabilities.t()
| nil,
digestFunctions: [String.t()] | nil,
maxBatchTotalSizeBytes: String.t() | nil,
supportedCompressors: [String.t()] | nil,
symlinkAbsolutePathStrategy: String.t() | nil
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.