GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2DirectoryNode (google_api_remote_build_execution v0.23.0) View Source
A DirectoryNode represents a child of a Directory which is itself a Directory and its associated metadata.
Attributes
-
digest(type:GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2Digest.t, default:nil) - The digest of the Directory object represented. See Digest for information about how to take the digest of a proto message. -
name(type:String.t, default:nil) - The name of the directory.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() ::
%GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2DirectoryNode{
digest:
GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2Digest.t()
| nil,
name: String.t() | nil
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.