GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2ExecuteOperationMetadata (google_api_remote_build_execution v0.23.0) View Source
Metadata about an ongoing execution, which will be contained in the metadata field of the Operation.
Attributes
-
actionDigest(type:GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2Digest.t, default:nil) - The digest of the Action being executed. -
stage(type:String.t, default:nil) - The current stage of execution. -
stderrStreamName(type:String.t, default:nil) - If set, the client can use this resource name with ByteStream.Read to stream the standard error from the endpoint hosting streamed responses. -
stdoutStreamName(type:String.t, default:nil) - If set, the client can use this resource name with ByteStream.Read to stream the standard output from the endpoint hosting streamed responses.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() ::
%GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2ExecuteOperationMetadata{
actionDigest:
GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2Digest.t()
| nil,
stage: String.t() | nil,
stderrStreamName: String.t() | nil,
stdoutStreamName: String.t() | nil
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.