GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2ExecutedActionMetadata (google_api_remote_build_execution v0.23.0) View Source
ExecutedActionMetadata contains details about a completed execution.
Attributes
-
auxiliaryMetadata(type:list(map()), default:nil) - Details that are specific to the kind of worker used. For example, on POSIX-like systems this could contain a message with getrusage(2) statistics. -
executionCompletedTimestamp(type:DateTime.t, default:nil) - When the worker completed executing the action command. -
executionStartTimestamp(type:DateTime.t, default:nil) - When the worker started executing the action command. -
inputFetchCompletedTimestamp(type:DateTime.t, default:nil) - When the worker finished fetching action inputs. -
inputFetchStartTimestamp(type:DateTime.t, default:nil) - When the worker started fetching action inputs. -
outputUploadCompletedTimestamp(type:DateTime.t, default:nil) - When the worker finished uploading action outputs. -
outputUploadStartTimestamp(type:DateTime.t, default:nil) - When the worker started uploading action outputs. -
queuedTimestamp(type:DateTime.t, default:nil) - When was the action added to the queue. -
worker(type:String.t, default:nil) - The name of the worker which ran the execution. -
workerCompletedTimestamp(type:DateTime.t, default:nil) - When the worker completed the action, including all stages. -
workerStartTimestamp(type:DateTime.t, default:nil) - When the worker received the action.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() ::
%GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2ExecutedActionMetadata{
auxiliaryMetadata: [map()] | nil,
executionCompletedTimestamp: DateTime.t() | nil,
executionStartTimestamp: DateTime.t() | nil,
inputFetchCompletedTimestamp: DateTime.t() | nil,
inputFetchStartTimestamp: DateTime.t() | nil,
outputUploadCompletedTimestamp: DateTime.t() | nil,
outputUploadStartTimestamp: DateTime.t() | nil,
queuedTimestamp: DateTime.t() | nil,
worker: String.t() | nil,
workerCompletedTimestamp: DateTime.t() | nil,
workerStartTimestamp: DateTime.t() | nil
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.