GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2GetTreeResponse (google_api_remote_build_execution v0.23.0) View Source
A response message for ContentAddressableStorage.GetTree.
Attributes
-
directories(type:list(GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2Directory.t), default:nil) - The directories descended from the requested root. -
nextPageToken(type:String.t, default:nil) - If present, signifies that there are more results which the client can retrieve by passing this as the page_token in a subsequent request. If empty, signifies that this is the last page of results.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() ::
%GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2GetTreeResponse{
directories:
[
GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2Directory.t()
]
| nil,
nextPageToken: String.t() | nil
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.