GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2LogFile (google_api_remote_build_execution v0.23.0) View Source
A LogFile is a log stored in the CAS.
Attributes
-
digest(type:GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2Digest.t, default:nil) - The digest of the log contents. -
humanReadable(type:boolean(), default:nil) - This is a hint as to the purpose of the log, and is set to true if the log is human-readable text that can be usefully displayed to a user, and false otherwise. For instance, if a command-line client wishes to print the server logs to the terminal for a failed action, this allows it to avoid displaying a binary file.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() ::
%GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2LogFile{
digest:
GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2Digest.t()
| nil,
humanReadable: boolean() | nil
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.