GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2NodeProperty (google_api_remote_build_execution v0.23.0) View Source
A single property for FileNodes, DirectoryNodes, and SymlinkNodes. The server is responsible for specifying the property names that it accepts. If permitted by the server, the same name may occur multiple times.
Attributes
-
name(type:String.t, default:nil) - The property name. -
value(type:String.t, default:nil) - The property value.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.