GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2OutputSymlink (google_api_remote_build_execution v0.23.0) View Source
An OutputSymlink is similar to a Symlink, but it is used as an output in an ActionResult. OutputSymlink is binary-compatible with SymlinkNode.
Attributes
-
nodeProperties(type:GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2NodeProperties.t, default:nil) - -
path(type:String.t, default:nil) - The full path of the symlink relative to the working directory, including the filename. The path separator is a forward slash/. Since this is a relative path, it MUST NOT begin with a leading forward slash. -
target(type:String.t, default:nil) - The target path of the symlink. The path separator is a forward slash/. The target path can be relative to the parent directory of the symlink or it can be an absolute path starting with/. Support for absolute paths can be checked using the Capabilities API...components are allowed anywhere in the target path.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() ::
%GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2OutputSymlink{
nodeProperties:
GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2NodeProperties.t()
| nil,
path: String.t() | nil,
target: String.t() | nil
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.