GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2Platform (google_api_remote_build_execution v0.23.0) View Source
A Platform is a set of requirements, such as hardware, operating system, or compiler toolchain, for an Action's execution environment. A Platform is represented as a series of key-value pairs representing the properties that are required of the platform.
Attributes
-
properties(type:list(GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2PlatformProperty.t), default:nil) - The properties that make up this platform. In order to ensure that equivalentPlatforms always hash to the same value, the properties MUST be lexicographically sorted by name, and then by value. Sorting of strings is done by code point, equivalently, by the UTF-8 bytes.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() ::
%GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2Platform{
properties:
[
GoogleApi.RemoteBuildExecution.V2.Model.BuildBazelRemoteExecutionV2PlatformProperty.t()
]
| nil
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.