GoogleApi.RemoteBuildExecution.V2.Model.GoogleDevtoolsRemotebuildbotCommandDurations (google_api_remote_build_execution v0.23.0) View Source
CommandDuration contains the various duration metrics tracked when a bot performs a command.
Attributes
-
casRelease(type:String.t, default:nil) - The time spent to release the CAS blobs used by the task. -
cmWaitForAssignment(type:String.t, default:nil) - The time spent waiting for Container Manager to assign an asynchronous container for execution. -
dockerPrep(type:String.t, default:nil) - The time spent preparing the command to be run in a Docker container (includes pulling the Docker image, if necessary). -
dockerPrepStartTime(type:DateTime.t, default:nil) - The timestamp when docker preparation begins. -
download(type:String.t, default:nil) - The time spent downloading the input files and constructing the working directory. -
downloadStartTime(type:DateTime.t, default:nil) - The timestamp when downloading the input files begins. -
execStartTime(type:DateTime.t, default:nil) - The timestamp when execution begins. -
execution(type:String.t, default:nil) - The time spent executing the command (i.e., doing useful work). -
isoPrepDone(type:DateTime.t, default:nil) - The timestamp when preparation is done and bot starts downloading files. -
overall(type:String.t, default:nil) - The time spent completing the command, in total. -
stdout(type:String.t, default:nil) - The time spent uploading the stdout logs. -
upload(type:String.t, default:nil) - The time spent uploading the output files. -
uploadStartTime(type:DateTime.t, default:nil) - The timestamp when uploading the output files begins.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() ::
%GoogleApi.RemoteBuildExecution.V2.Model.GoogleDevtoolsRemotebuildbotCommandDurations{
casRelease: String.t() | nil,
cmWaitForAssignment: String.t() | nil,
dockerPrep: String.t() | nil,
dockerPrepStartTime: DateTime.t() | nil,
download: String.t() | nil,
downloadStartTime: DateTime.t() | nil,
execStartTime: DateTime.t() | nil,
execution: String.t() | nil,
isoPrepDone: DateTime.t() | nil,
overall: String.t() | nil,
stdout: String.t() | nil,
upload: String.t() | nil,
uploadStartTime: DateTime.t() | nil
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.