GoogleApi.RemoteBuildExecution.V2.Model.GoogleDevtoolsRemotebuildbotCommandEvents (google_api_remote_build_execution v0.23.0) View Source
CommandEvents contains counters for the number of warnings and errors that occurred during the execution of a command.
Attributes
-
cmUsage(type:String.t, default:nil) - Indicates if and how Container Manager is being used for task execution. -
dockerCacheHit(type:boolean(), default:nil) - Indicates whether we are using a cached Docker image (true) or had to pull the Docker image (false) for this command. -
dockerImageName(type:String.t, default:nil) - Docker Image name. -
inputCacheMiss(type:number(), default:nil) - The input cache miss ratio. -
numErrors(type:String.t, default:nil) - The number of errors reported. -
numWarnings(type:String.t, default:nil) - The number of warnings reported. -
outputLocation(type:String.t, default:nil) - Indicates whether output files and/or output directories were found relative to the execution root or to the user provided work directory or both or none. -
usedAsyncContainer(type:boolean(), default:nil) - Indicates whether an asynchronous container was used for execution.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() ::
%GoogleApi.RemoteBuildExecution.V2.Model.GoogleDevtoolsRemotebuildbotCommandEvents{
cmUsage: String.t() | nil,
dockerCacheHit: boolean() | nil,
dockerImageName: String.t() | nil,
inputCacheMiss: number() | nil,
numErrors: String.t() | nil,
numWarnings: String.t() | nil,
outputLocation: String.t() | nil,
usedAsyncContainer: boolean() | nil
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.