GoogleApi.RemoteBuildExecution.V2.Model.GoogleDevtoolsRemotebuildexecutionAdminV1alphaCreateInstanceRequest (google_api_remote_build_execution v0.23.0) View Source
The request used for CreateInstance.
Attributes
-
instance(type:GoogleApi.RemoteBuildExecution.V2.Model.GoogleDevtoolsRemotebuildexecutionAdminV1alphaInstance.t, default:nil) - Specifies the instance to create. The name in the instance, if specified in the instance, is ignored. -
instanceId(type:String.t, default:nil) - ID of the created instance. A validinstance_idmust: be 6-50 characters long, contain only lowercase letters, digits, hyphens and underscores, start with a lowercase letter, and end with a lowercase letter or a digit. -
parent(type:String.t, default:nil) - Resource name of the project containing the instance. Format:projects/[PROJECT_ID].
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() ::
%GoogleApi.RemoteBuildExecution.V2.Model.GoogleDevtoolsRemotebuildexecutionAdminV1alphaCreateInstanceRequest{
instance:
GoogleApi.RemoteBuildExecution.V2.Model.GoogleDevtoolsRemotebuildexecutionAdminV1alphaInstance.t()
| nil,
instanceId: String.t() | nil,
parent: String.t() | nil
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.