GoogleApi.RemoteBuildExecution.V2.Model.GoogleDevtoolsRemotebuildexecutionAdminV1alphaCreateWorkerPoolRequest (google_api_remote_build_execution v0.23.0) View Source
The request used for CreateWorkerPool.
Attributes
-
parent(type:String.t, default:nil) - Resource name of the instance in which to create the new worker pool. Format:projects/[PROJECT_ID]/instances/[INSTANCE_ID]. -
poolId(type:String.t, default:nil) - ID of the created worker pool. A valid pool ID must: be 6-50 characters long, contain only lowercase letters, digits, hyphens and underscores, start with a lowercase letter, and end with a lowercase letter or a digit. -
workerPool(type:GoogleApi.RemoteBuildExecution.V2.Model.GoogleDevtoolsRemotebuildexecutionAdminV1alphaWorkerPool.t, default:nil) - Specifies the worker pool to create. The name in the worker pool, if specified, is ignored.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() ::
%GoogleApi.RemoteBuildExecution.V2.Model.GoogleDevtoolsRemotebuildexecutionAdminV1alphaCreateWorkerPoolRequest{
parent: String.t() | nil,
poolId: String.t() | nil,
workerPool:
GoogleApi.RemoteBuildExecution.V2.Model.GoogleDevtoolsRemotebuildexecutionAdminV1alphaWorkerPool.t()
| nil
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.