GoogleApi.RemoteBuildExecution.V2.Model.GoogleDevtoolsRemotebuildexecutionAdminV1alphaInstance (google_api_remote_build_execution v0.23.0) View Source
Instance conceptually encapsulates all Remote Build Execution resources for remote builds. An instance consists of storage and compute resources (for example, ContentAddressableStorage, ActionCache, WorkerPools) used for running remote builds. All Remote Build Execution API calls are scoped to an instance.
Attributes
-
featurePolicy(type:GoogleApi.RemoteBuildExecution.V2.Model.GoogleDevtoolsRemotebuildexecutionAdminV1alphaFeaturePolicy.t, default:nil) - The policy to define whether or not RBE features can be used or how they can be used. -
location(type:String.t, default:nil) - The location is a GCP region. Currently onlyus-central1is supported. -
loggingEnabled(type:boolean(), default:nil) - Output only. Whether stack driver logging is enabled for the instance. -
name(type:String.t, default:nil) - Output only. Instance resource name formatted as:projects/[PROJECT_ID]/instances/[INSTANCE_ID]. Name should not be populated when creating an instance since it is provided in theinstance_idfield. -
state(type:String.t, default:nil) - Output only. State of the instance.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() ::
%GoogleApi.RemoteBuildExecution.V2.Model.GoogleDevtoolsRemotebuildexecutionAdminV1alphaInstance{
featurePolicy:
GoogleApi.RemoteBuildExecution.V2.Model.GoogleDevtoolsRemotebuildexecutionAdminV1alphaFeaturePolicy.t()
| nil,
location: String.t() | nil,
loggingEnabled: boolean() | nil,
name: String.t() | nil,
state: String.t() | nil
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.