GoogleApi.RemoteBuildExecution.V2.Model.GoogleDevtoolsRemotebuildexecutionAdminV1alphaUpdateInstanceRequest (google_api_remote_build_execution v0.23.0) View Source
The request used for UpdateInstance.
Attributes
-
instance(type:GoogleApi.RemoteBuildExecution.V2.Model.GoogleDevtoolsRemotebuildexecutionAdminV1alphaInstance.t, default:nil) - Specifies the instance to update. -
loggingEnabled(type:boolean(), default:nil) - Deprecated, use instance.logging_enabled instead. Whether to enable Stackdriver logging for this instance. -
name(type:String.t, default:nil) - Deprecated, use instance.Name instead. Name of the instance to update. Format:projects/[PROJECT_ID]/instances/[INSTANCE_ID]. -
updateMask(type:String.t, default:nil) - The update mask applies to instance. For theFieldMaskdefinition, see https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask If an empty update_mask is provided, only the non-default valued field in the worker pool field will be updated. Note that in order to update a field to the default value (zero, false, empty string) an explicit update_mask must be provided.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() ::
%GoogleApi.RemoteBuildExecution.V2.Model.GoogleDevtoolsRemotebuildexecutionAdminV1alphaUpdateInstanceRequest{
instance:
GoogleApi.RemoteBuildExecution.V2.Model.GoogleDevtoolsRemotebuildexecutionAdminV1alphaInstance.t()
| nil,
loggingEnabled: boolean() | nil,
name: String.t() | nil,
updateMask: String.t() | nil
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.