GoogleApi.RemoteBuildExecution.V2.Model.GoogleDevtoolsRemotebuildexecutionAdminV1alphaWorkerPool (google_api_remote_build_execution v0.23.0) View Source
A worker pool resource in the Remote Build Execution API.
Attributes
-
autoscale(type:GoogleApi.RemoteBuildExecution.V2.Model.GoogleDevtoolsRemotebuildexecutionAdminV1alphaAutoscale.t, default:nil) - The autoscale policy to apply on a pool. -
channel(type:String.t, default:nil) - Channel specifies the release channel of the pool. -
name(type:String.t, default:nil) - WorkerPool resource name formatted as:projects/[PROJECT_ID]/instances/[INSTANCE_ID]/workerpools/[POOL_ID]. name should not be populated when creating a worker pool since it is provided in thepoolIdfield. -
state(type:String.t, default:nil) - Output only. State of the worker pool. -
workerConfig(type:GoogleApi.RemoteBuildExecution.V2.Model.GoogleDevtoolsRemotebuildexecutionAdminV1alphaWorkerConfig.t, default:nil) - Specifies the properties, such as machine type and disk size, used for creating workers in a worker pool. -
workerCount(type:String.t, default:nil) - The desired number of workers in the worker pool. Must be a value between 0 and 15000.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() ::
%GoogleApi.RemoteBuildExecution.V2.Model.GoogleDevtoolsRemotebuildexecutionAdminV1alphaWorkerPool{
autoscale:
GoogleApi.RemoteBuildExecution.V2.Model.GoogleDevtoolsRemotebuildexecutionAdminV1alphaAutoscale.t()
| nil,
channel: String.t() | nil,
name: String.t() | nil,
state: String.t() | nil,
workerConfig:
GoogleApi.RemoteBuildExecution.V2.Model.GoogleDevtoolsRemotebuildexecutionAdminV1alphaWorkerConfig.t()
| nil,
workerCount: String.t() | nil
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.