GoogleApi.RemoteBuildExecution.V2.Model.GoogleDevtoolsRemoteworkersV1test2DirectoryMetadata (google_api_remote_build_execution v0.23.0) View Source
The metadata for a directory. Similar to the equivalent message in the Remote Execution API.
Attributes
-
digest(type:GoogleApi.RemoteBuildExecution.V2.Model.GoogleDevtoolsRemoteworkersV1test2Digest.t, default:nil) - A pointer to the contents of the directory, in the form of a marshalled Directory message. -
path(type:String.t, default:nil) - The path of the directory, as in FileMetadata.path.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() ::
%GoogleApi.RemoteBuildExecution.V2.Model.GoogleDevtoolsRemoteworkersV1test2DirectoryMetadata{
digest:
GoogleApi.RemoteBuildExecution.V2.Model.GoogleDevtoolsRemoteworkersV1test2Digest.t()
| nil,
path: String.t() | nil
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.